module Fog
  module Compute
    class XenServer
      module Models
        autoload :Blob, File.expand_path("../models/blob", __FILE__)
        autoload :Blobs, File.expand_path("../models/blobs", __FILE__)
        autoload :Bond, File.expand_path("../models/bond", __FILE__)
        autoload :Bonds, File.expand_path("../models/bonds", __FILE__)
        autoload :ClassMethods, File.expand_path("../models/class_methods", __FILE__)
        autoload :Collection, File.expand_path("../models/collection", __FILE__)
        autoload :Console, File.expand_path("../models/console", __FILE__)
        autoload :Consoles, File.expand_path("../models/consoles", __FILE__)
        autoload :CrashDump, File.expand_path("../models/crash_dump", __FILE__)
        autoload :CrashDumps, File.expand_path("../models/crash_dumps", __FILE__)
        autoload :DrTask, File.expand_path("../models/dr_task", __FILE__)
        autoload :DrTasks, File.expand_path("../models/dr_tasks", __FILE__)
        autoload :GpuGroup, File.expand_path("../models/gpu_group", __FILE__)
        autoload :GpuGroups, File.expand_path("../models/gpu_groups", __FILE__)
        autoload :GuestMetrics, File.expand_path("../models/guest_metrics", __FILE__)
        autoload :GuestsMetrics, File.expand_path("../models/guests_metrics", __FILE__)
        autoload :Host, File.expand_path("../models/host", __FILE__)
        autoload :HostCpu, File.expand_path("../models/host_cpu", __FILE__)
        autoload :HostCpus, File.expand_path("../models/host_cpus", __FILE__)
        autoload :HostCrashDump, File.expand_path("../models/host_crash_dump", __FILE__)
        autoload :HostCrashDumps, File.expand_path("../models/host_crash_dumps", __FILE__)
        autoload :HostMetrics, File.expand_path("../models/host_metrics", __FILE__)
        autoload :HostPatch, File.expand_path("../models/host_patch", __FILE__)
        autoload :HostPatchs, File.expand_path("../models/host_patchs", __FILE__)
        autoload :Hosts, File.expand_path("../models/hosts", __FILE__)
        autoload :HostsMetrics, File.expand_path("../models/hosts_metrics", __FILE__)
        autoload :InstanceMethods, File.expand_path("../models/instance_methods", __FILE__)
        autoload :Model, File.expand_path("../models/model", __FILE__)
        autoload :Network, File.expand_path("../models/network", __FILE__)
        autoload :Networks, File.expand_path("../models/networks", __FILE__)
        autoload :Pbd, File.expand_path("../models/pbd", __FILE__)
        autoload :Pbds, File.expand_path("../models/pbds", __FILE__)
        autoload :Pci, File.expand_path("../models/pci", __FILE__)
        autoload :Pcis, File.expand_path("../models/pcis", __FILE__)
        autoload :Pgpu, File.expand_path("../models/pgpu", __FILE__)
        autoload :Pgpus, File.expand_path("../models/pgpus", __FILE__)
        autoload :Pif, File.expand_path("../models/pif", __FILE__)
        autoload :PifMetrics, File.expand_path("../models/pif_metrics", __FILE__)
        autoload :Pifs, File.expand_path("../models/pifs", __FILE__)
        autoload :PifsMetrics, File.expand_path("../models/pifs_metrics", __FILE__)
        autoload :Pool, File.expand_path("../models/pool", __FILE__)
        autoload :PoolPatch, File.expand_path("../models/pool_patch", __FILE__)
        autoload :PoolPatchs, File.expand_path("../models/pool_patchs", __FILE__)
        autoload :Pools, File.expand_path("../models/pools", __FILE__)
        autoload :Role, File.expand_path("../models/role", __FILE__)
        autoload :Roles, File.expand_path("../models/roles", __FILE__)
        autoload :Server, File.expand_path("../models/server", __FILE__)
        autoload :ServerAppliance, File.expand_path("../models/server_appliance", __FILE__)
        autoload :ServerAppliances, File.expand_path("../models/server_appliances", __FILE__)
        autoload :ServerMetrics, File.expand_path("../models/server_metrics", __FILE__)
        autoload :ServersMetrics, File.expand_path("../models/servers_metrics", __FILE__)
        autoload :Servers, File.expand_path("../models/servers", __FILE__)
        autoload :StorageManager, File.expand_path("../models/storage_manager", __FILE__)
        autoload :StorageManagers, File.expand_path("../models/storage_managers", __FILE__)
        autoload :StorageRepositories, File.expand_path("../models/storage_repositories", __FILE__)
        autoload :StorageRepository, File.expand_path("../models/storage_repository", __FILE__)
        autoload :Tunnel, File.expand_path("../models/tunnel", __FILE__)
        autoload :Tunnels, File.expand_path("../models/tunnels", __FILE__)
        autoload :Vbd, File.expand_path("../models/vbd", __FILE__)
        autoload :VbdMetrics, File.expand_path("../models/vbd_metrics", __FILE__)
        autoload :Vbds, File.expand_path("../models/vbds", __FILE__)
        autoload :VbdsMetrics, File.expand_path("../models/vbds_metrics", __FILE__)
        autoload :Vdi, File.expand_path("../models/vdi", __FILE__)
        autoload :Vdis, File.expand_path("../models/vdis", __FILE__)
        autoload :Vif, File.expand_path("../models/vif", __FILE__)
        autoload :VifMetrics, File.expand_path("../models/vif_metrics", __FILE__)
        autoload :Vifs, File.expand_path("../models/vifs", __FILE__)
        autoload :VifsMetrics, File.expand_path("../models/vifs_metrics", __FILE__)
        autoload :Vlan, File.expand_path("../models/vlan", __FILE__)
        autoload :Vlans, File.expand_path("../models/vlans", __FILE__)
        autoload :Vmpp, File.expand_path("../models/vmpp", __FILE__)
        autoload :Vmpps, File.expand_path("../models/vmpps", __FILE__)
        autoload :Vtpm, File.expand_path("../models/vtpm", __FILE__)
        autoload :Vtpms, File.expand_path("../models/vtpms", __FILE__)
      end
    end
  end
end